//  2012 SAP AG. All rights reserved.
// Author : SAP.

var logDirectory;
var listOfLogFiles;
var listOfLogFilesNames;
var listOfLogFilesLevels;

/**
 * Function to request File System for entire app
 */
function getFileSystem()
{
	    //Requesting the File System.
	
	    if(window.cordova)
		{
		       
	    		window.requestFileSystem(LocalFileSystem.PERSISTENT, 0, gotFileSystem, failFileSystem);
			
		}
	    		
	    else
	    {
	       //console.log("File System could not be created because of Phonegap issue. Launching the app now. Log files wont be saved.");
	       
	       if(!app)
	       		appCreate();  
	    }   
}

/**
 * Success CallBack Function for File system request
 */
function gotFileSystem(receivedFileSystem)
{
	     //console.log("File System Received. Creating Log Directory");    
	     fileSystem = receivedFileSystem;
	     
	     //Creating Log Directory
         createLogDirectory();
}

/**
 * Failure CallBack Function for File system request
 */
function failFileSystem(error)
{
         //console.log("Error in getting File System.Logs wont be saved.Error is "+(error.code)+" Launching the app now");
         if(!app)
         		appCreate();
}

/**
 * Create Log Directory
 */

function createLogDirectory()
{
    
    /* Change the Log Path depending on the Device. ie iOS or Android
     * 
     * Logs for iOS will be stored in Application SandBox. Path: Documents/Logs
     * 
     * Logs for Android will be saved on internal storage, private to the app. Path: /data/data/com.sap.b2c.mLoyalty/Logs
     * 
     * */
    		 	
	if (device.platform.match("Android"))
	{
		//console.log("Creating Log Directory for Android");
		fileSystem.root.getDirectory("SAPCustomerLoyaltyActivity",{create: true}, gotLogDirectory, failLogDirectory);
	}
		 	
	else
	{
		//console.log("Creating Log Directoty for iOS");
		fileSystem.root.getDirectory("Logs",{create: true}, gotLogDirectory, failLogDirectory);
	}

}

/**
 * Success Callback for createLogDirectory()
 * 
 * @param {} directoryReceived
 */
function gotLogDirectory(directoryReceived)
{  
     //console.log("Directory Created at"+directoryReceived.fullPath);
     //console.log("Creating Log Files");
     createLogFiles();
}

function failLogDirectory(error)
{
	//console.log("Log directory couldnot be created. Launching the app now. Error is "+error.code + "Launching the app now");
	if(!app)
			appCreate();
}

function createLogFiles()
{
    try
    {
	    //console.log("Parsing LoggingConfig.xml");
	    var xmlDoc = loadXML("app/common/LoggingConfig.xml");
	     	
	    var listOfLogFilesXML = xmlDoc.getElementsByTagName("filename");
			
		listOfLogFiles = [];
		listOfLogFilesLevels =[];
		listOfLogFilesNames = [];
		
		//console.log(listOfLogFilesXML.length+" log files to be created");
		
		if(xmlDoc.getElementsByTagName("version").length!=0)
			version = xmlDoc.getElementsByTagName("version")[0].getAttribute("number");
					
		for(var i=0;i<listOfLogFilesXML.length;i++)
		{
			listOfLogFilesNames.push(xmlDoc.getElementsByTagName("logger")[i].getAttribute("name"));
			listOfLogFiles.push(xmlDoc.getElementsByTagName("filename")[i].childNodes[0].nodeValue);
		    listOfLogFilesLevels.push(xmlDoc.getElementsByTagName("level")[i].childNodes[0].nodeValue);
		}
	    
		for(var i=0;i<listOfLogFilesNames.length;i++)
		{
			if(listOfLogFilesNames[i]=="TechnicalLog")
			{
				//Set the Technical Log File Level
				//console.log("Setting the TechnicalLog file level to "+listOfLogFilesLevels[i]);
				
				setTechnicalLogLevel(listOfLogFilesLevels[i]);
										
	    		if (device.platform.match("Android"))
				{
	    			//console.log("Creating Technical Log file for Android "+listOfLogFiles[i]);
	    			fileSystem.root.getFile("SAPCustomerLoyaltyActivity/"+listOfLogFiles[i], {create: true}, gotTechnicalLogFileEntry, failTechincalLogFileEntry);		

				}
				
				else
				{
					//console.log("Creating Technical Log file for iOS "+listOfLogFiles[i]);
					fileSystem.root.getFile("Logs/"+listOfLogFiles[i], {create: true}, gotTechnicalLogFileEntry, failTechincalLogFileEntry);		
				}
			}
	
		}
    }
    
    catch(exception)
    {
        //console.log("Error in parsing the XML file. Exception is "+exception+"Launching App now");
        
        if(!app)
			appCreate();
    }
    
}
