//  2012 SAP AG. All rights reserved.
// Author : SAP.

/**
 * 
 * Global Variable Declaration 
 */

var technicalLogFile;
var technicalLogFileEntry;
var technicalLogFileWriter;
var technicalLog;
var technicalLogsPool=[ ];
var boolTechincalLogProcessing = false;

/**
 * 	Function to set the Log level for the Client Side to any of the following
 * 
 * 	jQuery.sap.log.Level.FATAL Fatal level(0).
 *	jQuery.sap.log.Level.ERROR Error level(1).
 *	jQuery.sap.log.Level.WARNING Warning level(2).	
 *	jQuery.sap.log.Level.INFO Info level(3).
 *	jQuery.sap.log.Level.DEBUG Debug level(4).
 *	jQuery.sap.log.Level.TRACE Trace level(5).
 * 	jQuery.sap.log.Level.NONE Do not log anything
 *
 *  Higher numeric values represent less important levels
 * 
 *  Setting it to jQuery.sap.log.Level.DEBUG for development purposes
 * 
 * 	@param {jQuery.sap.log.Level} logLevel
 */


function setTechnicalLogLevel(logLevel) 
{
	if(logLevel == "FATAL")
			logLevel = jQuery.sap.log.Level.FATAL;
			
    else if(logLevel == "ERROR")
    			logLevel = jQuery.sap.log.Level.ERROR;
    			
    else if(logLevel == "WARNING")
    			logLevel = jQuery.sap.log.Level.WARNING;
    	
    else if(logLevel == "INFO")
    			logLevel = jQuery.sap.log.Level.INFO;
    			
    else if(logLevel == "DEBUG")
    			logLevel = jQuery.sap.log.Level.DEBUG;
    	
    else if(logLevel == "TRACE")
    			logLevel = jQuery.sap.log.Level.TRACE;
    			
    else if(logLevel == "OFF")
    			logLevel = jQuery.sap.log.Level.NONE;

	//Set Log Level for Technical Log
	jQuery.sap.log.setLevel(logLevel, "Technical");

}

/**
 * Creates a new fatal-level entry in the log with the given message, details and calling component.
 *
 * @param {} message Message text to display
 * @param {} detail Details about the message, might be omitted
 * @param {} component Name of the component that produced the log entry
 */


function logTechnicalFatal(message,detail)
{
	var oldLogCount = jQuery.sap.log.getLogEntries().length;
	
	jQuery.sap.log.fatal(message,detail,"Technical");
	
	var newLogCount = jQuery.sap.log.getLogEntries().length;
	
	/*TODO Attach  a loglistener 
	 *     Pass a JS Object to it(oListener)
	 *     Have a method in it called "onLogEntry"
	 *     
	 *     jQuery.sap.log.addLogListener(oListener)
	 *     
	 *     Returns {jQuery.sap.log}	 The global logger

	 *     */
	
	if(oldLogCount!=newLogCount)
	{
		//Check if Technical log file is created. Log the statements only when file is created. 
		if(technicalLogFileEntry)
		{
			addLogToTechnicalLogPool(jQuery.sap.log.getLogEntries()[jQuery.sap.log.getLogEntries().length-1]);
		}
	}
}

/**
 * Creates a new error-level entry in the log with the given message, details and calling component.
 *
 * @param {} message Message text to display
 * @param {} detail Details about the message, might be omitted
 * @param {} component Name of the component that produced the log entry
 */
function logTechnicalError(message,detail)
{
	var oldLogCount = jQuery.sap.log.getLogEntries().length;

	jQuery.sap.log.error(message,detail,"Technical");

	var newLogCount = jQuery.sap.log.getLogEntries().length;

	if(oldLogCount!=newLogCount)
	{
		//Check if Technical log file is created. Log the statements only when file is created. 
		if(technicalLogFileEntry)
		{
			addLogToTechnicalLogPool(jQuery.sap.log.getLogEntries()[jQuery.sap.log.getLogEntries().length-1]);
		}
	}

}

/**
 * Creates a new warning-level entry in the log with the given message, details and calling component.
 *
 * @param {} message Message text to display
 * @param {} detail Details about the message, might be omitted
 * @param {} component Name of the component that produced the log entry
 */
function logTechnicalWarning(message,detail)
{	
	var oldLogCount = jQuery.sap.log.getLogEntries().length;
	
	jQuery.sap.log.warning(message,detail,"Technical");
	
	var newLogCount = jQuery.sap.log.getLogEntries().length;
	
	if(oldLogCount!=newLogCount)
	{
		//Check if Technical log file is created. Log the statements only when file is created. 
		if(technicalLogFileEntry)
		{
			addLogToTechnicalLogPool(jQuery.sap.log.getLogEntries()[jQuery.sap.log.getLogEntries().length-1]);
		}
	}
}
/**
 * Creates a new info-level entry in the log with the given message, details and calling component.
 *
 * @param {} message Message text to display
 * @param {} detail Details about the message, might be omitted
 * @param {} component Name of the component that produced the log entry
 */
function logTechnicalInfo(message,detail)
{
	var oldLogCount = jQuery.sap.log.getLogEntries().length;

	jQuery.sap.log.info(message,detail,"Technical");
	
	var newLogCount = jQuery.sap.log.getLogEntries().length;
	
	if(oldLogCount!=newLogCount)
	{
		//Check if Technical log file is created. Log the statements only when file is created. 
		if(technicalLogFileEntry)
		{
			addLogToTechnicalLogPool(jQuery.sap.log.getLogEntries()[jQuery.sap.log.getLogEntries().length-1]);
		}
	}	
}

/**
 * Creates a new debug-level entry in the log with the given message, details and calling component.
 *
 * @param {} message Message text to display
 * @param {} detail Details about the message, might be omitted
 * @param {} component Name of the component that produced the log entry
 */
function logTechnicalDebug(message,detail)
{
	var oldLogCount = jQuery.sap.log.getLogEntries().length;

	jQuery.sap.log.debug(message,detail,"Technical");
	
	var newLogCount = jQuery.sap.log.getLogEntries().length;

	if(oldLogCount!=newLogCount)
	{
		//Check if Technical log file is created. Log the statements only when file is created. 
		if(technicalLogFileEntry)
		{
			addLogToTechnicalLogPool(jQuery.sap.log.getLogEntries()[jQuery.sap.log.getLogEntries().length-1]);
		}
	}
}


/**
 * Creates a new trace-level entry in the log with the given message, details and calling component.
 *
 * @param {} message Message text to display
 * @param {} detail Details about the message, might be omitted
 * @param {} component Name of the component that produced the log entry
 */
function logTechnicalTrace(message,detail)
{
	var oldLogCount = jQuery.sap.log.getLogEntries().length;

	jQuery.sap.log.trace(message,detail,"Technical");
	
	var newLogCount = jQuery.sap.log.getLogEntries().length;

	if(oldLogCount!=newLogCount)
	{
		//Check if Technical log file is created. Log the statements only when file is created. 
		if(technicalLogFileEntry)
		{
			addLogToTechnicalLogPool(jQuery.sap.log.getLogEntries()[jQuery.sap.log.getLogEntries().length-1]);
		}
	}	
}

/**
 * Success CallBack Function for createTechnicalLogFile
 * 
 * @param {} technicalFile - Techincal Log File created
 * 
 */
function gotTechnicalLogFileEntry(technicalLogFileEntryReceived)
{
	//console.log("Technical Log File Entry created at"+technicalLogFileEntryReceived.fullPath);
	technicalLogFileEntry = technicalLogFileEntryReceived;
	technicalLogFileEntry.file(gotTechnicalLogFile,failTechnicalLogFile);
}

function gotTechnicalLogFile(technicalLogFileReceived)
{
	//Creating the TechnicalLogFile Writer
	technicalLogFile = technicalLogFileReceived;
	technicalLogFileEntry.createWriter(gotTechnicalLogFileWriter, failTechnicalLogFileWriter);	   
}

function failTechnicalLogFile(error)
{
  	//console.log("Failed to create technical log file. Error is "+error.code+"Launching the app now");
  	
  	if(!app)
			appCreate();
}

/**
 * Success Callback Function for technicalLogFileReceived.createWriter
 * 
 * @param {} technicalLogFileWriterReceived - The received TechnicalLogFile writer
 */

function gotTechnicalLogFileWriter(technicalLogFileWriterReceived)
{
    //console.log("Technical File Writer Created");
    technicalLogFileWriter = technicalLogFileWriterReceived;
    
	technicalLogFileWriter.onwritestart = function(evt)  
	{
	  			boolTechincalLogProcessing = true;
	};
	  
	technicalLogFileWriter.onwriteend = function(evt) 
	{
				processTechnicalLogPool("callback");
	};     		
	  
	technicalLogFileWriter.onerror = function(evt)
    {
       		    //console.log("Techincal Log File. Write to file couldnot be performed"+evt.code);
    };
 
    for(var i=0;i<listOfLogFilesNames.length;i++)
	{
		if(listOfLogFilesNames[i]=="PerformanceLog")
		{
				//console.log("Setting the PerformanceLog file level to "+listOfLogFilesLevels[i]);
				setPerformanceLogLevel(listOfLogFilesLevels[i]);
				
				if (device.platform.match("Android"))
				{
    				//console.log("Creating Performance Log file for Android "+listOfLogFiles[i]);
    				fileSystem.root.getFile("SAPCustomerLoyaltyActivity/"+listOfLogFiles[i], {create: true}, gotPerformanceLogFileEntry, failPerformanceLogFileEntry);

				}
				else
				{
    				//console.log("Creating Performance Log file for iOS "+listOfLogFiles[i]);
    				fileSystem.root.getFile("Logs/"+listOfLogFiles[i], {create: true}, gotPerformanceLogFileEntry, failPerformanceLogFileEntry);
				}
		}

	} 										  

}

/**
 * Failure Callback Function for technicalLogFileReceived.createWriter
 * 
 * @param {} error
 */
function failTechnicalLogFileWriter(error)
{
   //console.log("Technical Log file writer could not be created." + error.code+"Launching the app now");
   if(!app)
   		appCreate();

}

/**
 * Failure CallBack Function for createTechnicalLogFile
 * @param {} error - Error in creating Technical Log file.
 */
function failTechincalLogFileEntry(error)
{
	//console.log("Technical Log file could not be created. "+error.code+"Launching the app now");	
	if(!app)
		appCreate(); 

}

/**
 * Function for adding the Log to a pool
 * @param {} log - Log to be stored in temp pool
 */
function addLogToTechnicalLogPool(technicalLog)
{	
	
	//Push the newest Log Entry to the log pool
	technicalLogsPool.push(technicalLog); 
	
		
	//Process the technical Log pool only if it is not being already processed and the file writer is also created. 
	if(!boolTechincalLogProcessing && technicalLogFileWriter)
		processTechnicalLogPool("forced");
}

/**
 * Function to process the Technical Log Pool
 * @param {} string
 */
function processTechnicalLogPool(string)
{	
  	boolTechincalLogProcessing = true;
   
    if(technicalLogFileWriter)
    {    	
    		//Fetching the oldest entry in the pool
    		
    	  if(technicalLogsPool.length>0)
    		{
    			technicalLog = technicalLogsPool.shift();	
    			
    			var levelOfLog="";
    			
	   			if(technicalLog)
	    		{	   				
	   				   if(technicalLog.level==0)
							levelOfLog = "FATAL"
								
						else if(technicalLog.level==1)
							levelOfLog = "ERROR"
								
						else if(technicalLog.level==2)
							levelOfLog = "WARNING"
										
						else if(technicalLog.level==3)
							levelOfLog = "INFO"
												
						else if(technicalLog.level==4)
							levelOfLog = "DEBUG"
														
						else if(technicalLog.level==5)
							levelOfLog = "TRACE"
	   					
	   					technicalLogFileWriter.seek(technicalLogFileWriter.length);
			
						technicalLogFileWriter.write("\n"+technicalLog.date+" "+technicalLog.time+"  "+levelOfLog+"  "+"["+technicalLog.message+"]  "+technicalLog.details);
	    
	    		}
	    	}
	    	
	    	else
	    	{
	    		boolTechincalLogProcessing = false;
	    	}
   	}
}

