//  2012 SAP AG. All rights reserved.
// Author : SAP.

/**
 * 
 * Global Variable Declaration 
 */

var userLogFile;
var userLogFileEntry;
var userLogFileWriter;
var userLog;
var userLogsPool=[ ];
var boolUserLogProcessing = false;

/**
 * 	Function to set the Log level for the Client Side to any of the following
 * 
 * 	jQuery.sap.log.Level.FATAL Fatal level(0).
 *	jQuery.sap.log.Level.ERROR Error level(1).
 *	jQuery.sap.log.Level.WARNING Warning level(2).	
 *	jQuery.sap.log.Level.INFO Info level(3).
 *	jQuery.sap.log.Level.DEBUG Debug level(4).
 *	jQuery.sap.log.Level.TRACE Trace level(5).
 * 	jQuery.sap.log.Level.NONE Do not log anything
 *
 *  Higher numeric values represent less important levels
 * 
 *  Setting it to jQuery.sap.log.Level.DEBUG for development purposes
 * 
 * 	@param {jQuery.sap.log.Level} logLevel
 */


function setUserLogLevel(logLevel) 
{
	
	if(logLevel == "ON")
		logLevel = jQuery.sap.log.Level.INFO;
		
	else if(logLevel == "OFF")
		logLevel = jQuery.sap.log.Level.NONE;
    			
	//Set Log Level for User Log

    jQuery.sap.log.setLevel(logLevel, "User");

}

/**
 * Creates a new info-level entry in the log with the given message, details and calling component.
 *
 * @param {} message Message text to display
 * @param {} detail Details about the message, might be omitted
 * @param {} component Name of the component that produced the log entry
 */
function logUserInfo(message,detail)
{
	var oldLogCount = jQuery.sap.log.getLogEntries().length;

	jQuery.sap.log.info(message,detail,"User");
	
	var newLogCount = jQuery.sap.log.getLogEntries().length;
	
	if(oldLogCount!=newLogCount)
	{
		//Check if User log file is created. Log the statements only when file is created. 

		if(userLogFileEntry)
		{
			addLogToUserLogPool(jQuery.sap.log.getLogEntries()[jQuery.sap.log.getLogEntries().length-1]);
		}
	}	
}


/**
 * Success CallBack Function for createUserLogFile
 * 
 * @param {} userFile - Techincal Log File created
 * 
 */
function gotUserLogFileEntry(userLogFileEntryReceived)
{
	//console.log("User Log File Entry created at"+userLogFileEntryReceived.fullPath);
	userLogFileEntry = userLogFileEntryReceived;
	userLogFileEntry.file(gotUserLogFile,failUserLogFile);
}

function gotUserLogFile(userLogFileReceived)
{
	//Creating the UserLogFile Writer
	userLogFile = userLogFileReceived;
	userLogFileEntry.createWriter(gotUserLogFileWriter, failUserLogFileWriter);	   
}

function failUserLogFile(error)
{
   	//console.log("Failed to create User log file. Error is "+error.code+"Launching the app now");
  	
  	if(!app)
			appCreate();
}

/**
 * Success Callback Function for userLogFileReceived.createWriter
 * 
 * @param {} userLogFileWriterReceived - The received UserLogFile writer
 */

function gotUserLogFileWriter(userLogFileWriterReceived)
{
    //console.log("User Log File Writer Created");
   
    userLogFileWriter = userLogFileWriterReceived;
   
    userLogFileWriter.onwritestart = function(evt)  
	  	{
	  		boolUserLogProcessing = true;
	};
	  
userLogFileWriter.onwriteend = function(evt) 
	  	{
		processUserLogPool("callback");
	};     		
	  
userLogFileWriter.onerror = function(evt)
	 	{
	        //console.log("User Log File. Write to file couldnot be performed"+evt.code);
	  	}

    //console.log("All the log files created. Launching app now");
    if(!app)
   		appCreate(); 
	
   	
     											  

}

/**
 * Failure Callback Function for userLogFileReceived.createWriter
 * 
 * @param {} error
 */
function failUserLogFileWriter(error)
{
   //console.log("User Log file writer could not be created. Still launching the app" + error.code);
   if(!app)
   		appCreate(); 

}

/**
 * Failure CallBack Function for createUserLogFile
 * @param {} error - Error in creating User Log file.
 */
function failUserLogFileEntry(error)
{
	//console.log("User Log file could not be created. Still launching the app"+error.code);	
	if(!app)
		appCreate(); 

}

/**
 * Function for adding the Log to a pool
 * @param {} log - Log to be stored in temp pool
 */
function addLogToUserLogPool(userLog)
{
	//Push the newest Log Entry to the log pool
	userLogsPool.push(userLog); 
		
	//Process the user Log pool only if it is not being already processed and the file writer is also created. 
	if(!boolUserLogProcessing && userLogFileWriter)
		processUserLogPool("forced");
}

/**
 * Function to process the User Log Pool
 * @param {} string
 */
function processUserLogPool(string)
{	
    boolUserLogProcessing = true;
    
	if(userLogFileWriter)
    	{    	
    		//Fetching the oldest entry in the pool
    		
    		if(userLogsPool.length>0)
    		{
    			userLog = userLogsPool.shift();	
    			
   			if(userLog)
    			{
					userLogFileWriter.seek(userLogFileWriter.length);
		
					userLogFileWriter.write(	
												"\n"+userLog.date+" "+userLog.time+"  "+
		                             			"File-Method:"+userLog.message+"  "+
		                             			"User Action:"+userLog.details
		                             		);
    			}
    		}
    	
    		else
    		{
    			boolUserLogProcessing = false;
    		}
   	}
}

