
function Utilities() {};

var isBusyDialogShown = false;

/*
 * The below function is to open a link in the device browser and
 * not within the phonegap web view. For Android we have an API
 * navigator.app.loadUrl() to do the same, but for iOS its not
 * there. So to achieve the same in iOS we have put a function
 * in the MainViewController.m file which listens to all url requests
 * and if any url is appended with string #phonegap=external, it opens
 * it in the iOS safari browser.
 */
Utilities.prototype.openExternalLink = function(url) {
	//console.log("Opening Ext URL " + url);
	  if (device.platform.match(/Android/)) {
	    navigator.app.loadUrl(url,{openExternal:true});
	  } else {
		  if((url.indexOf("tel:", 0)) == 0){
			  //in case of phone number, you already have the tel: protocol attached.
			  //No need for #phonegap-external
			  window.open(url);
		  }else{
			  window.open(url+"#phonegap=external");
		  }
	  }
}

// Wrote a cool parser to parse a node which can also have nested children and multiple nodes with same name
Utilities.prototype.processNode = function(node) {
	var objVal = {};
	var childNodesLength = node.childElementCount;
	
	for(var i=0; i < childNodesLength; i++) {
		if(node.childNodes[i].firstChild != null ) {
			var currentNode = node.childNodes[i];
			if(node.childNodes[i].firstChild.nodeValue !== null ) {
				objVal[node.childNodes[i].nodeName] = node.childNodes[i].firstChild.nodeValue;
			} else {
				if(node.getElementsByTagName(node.childNodes[i].nodeName).length > 1) {
					if(typeof(objVal[node.childNodes[i].nodeName]) == "undefined") {
						objVal[node.childNodes[i].nodeName] = [];
					}
					objVal[node.childNodes[i].nodeName].push(this.processNode(currentNode));
				}
				else
					objVal[node.childNodes[i].nodeName] = this.processNode(currentNode);
			}
		} else {
			objVal[node.childNodes[i].nodeName] = '';
		}
	}
	return objVal;
}

// This function can be used to parse the complete response coming from a web service
// Right now do not intend to use this function in the application but may try to use it in near future.
Utilities.prototype.processResponse = function(response, serviceResponseRoot) {
	var responseData = response.getElementsByTagName(serviceResponseRoot);
	var data = [];
	var dataObjXML = responseData[0];
	var dataObjVal = this.processNode(dataObjXML);			
	data.push(dataObjVal);
	return data[0];
}

Utilities.prototype.checkForUndefined = function(inputValue){
		if(inputValue == undefined || inputValue == null){
				return "";				
		}
		else{
				return inputValue;
		}
},

Utilities.prototype.createBusyDialog = function(textValue, titleValue) {
	//console.warn("isBusyDialogShown" + isBusyDialogShown);
	if(this.busyDialog == undefined) { 
		this.busyDialog = new sap.m.BusyDialog('UtilErrDialog',{text:textValue, title: titleValue});
	} else {
	    this.busyDialog.destroy();
	    this.busyDialog = new sap.m.BusyDialog('UtilErrDialog', { text: textValue, title: titleValue });
		//this.busyDialog.setText(textValue);
		//this.busyDialog.setTitle(titleValue);
	}
	this.busyDialog.open();
	isBusyDialogShown = true;
}

Utilities.prototype.closeBusyDialog = function() {
	if(this.busyDialog !== undefined) this.busyDialog.close();
	isBusyDialogShown = false;
}

Utilities.prototype.alertDialog = function( err_message, callback ){
		if(callback == undefined)
			callback = null;
		if(navigator.notification != undefined){
			navigator.notification.alert(
					err_message,       // message
					callback,          // callback
					oBundle.getText("Error"),  	// title
					oBundle.getText("OK")       // buttonText
			);
		}else{
			alert(err_message);
			if(callback != null)
				callback();
			//console.log(message);
			
		}
		/*if (this.errDialog == undefined){ 
				this.errDialog = new sap.m.Dialog({
						title: oBundle.getText("Error"), type : "Message",
						content : [
								new sap.m.Text({
										text: err_message,
										textAlign : "Center",
										wrapping : true
								})
						],
						leftButton: 
							new sap.m.Button({
								text: oBundle.getText("OK"),
								type: sap.m.ButtonType.Reject,
								tap : function() {
										util.closeErrDialog();
								}
							}),
				});
		}
		else {
				this.errDialog.destroy();
				this.errDialog = new sap.m.Dialog({
						title: oBundle.getText("Error"), type : "Message",
						content : [
								new sap.m.Text({
										text: err_message,
										textAlign : "Center",
										wrapping : true
								})
						],
						leftButton: 
							new sap.m.Button({
								text: oBundle.getText("OK"),
								type: sap.m.ButtonType.Reject,
								tap : function() {
										util.closeErrDialog();
								}
							}),
				});
		}
		this.errDialog.open();*/
}

Utilities.prototype.closeErrDialog = function() {
	if(this.errDialog !== undefined) this.errDialog.close();
}

Utilities.prototype.customDialogWithButton = function( err_message ){
		
		if ( app.getCurrentPage().sId == CREDENTIAL_SETTINGS_PAGE ){
				this.action = "signout";
				this.ButtonLabel = oBundle.getText("OK");
		}
		else if (app.getCurrentPage().sId == ID_LOGIN_PAGE){
				this.action = "forgotpw";
				this.ButtonLabel = oBundle.getText("forgot_password_but");
		}
		if (this.customDialog == undefined){ 
				this.customDialog = new sap.m.Dialog({
						title: oBundle.getText("Warning"), type : "Message",
						content : [
								new sap.m.Text({
										text: err_message,
										textAlign : "Center",
										wrapping : true
								})
						],
						leftButton: 
							new sap.m.Button({
								text: this.ButtonLabel,
								type: sap.m.ButtonType.Reject,
								tap : function() {
										util.closeCustomDialogWithButton();
								}
							}),
							rightButton: 
							new sap.m.Button({
								text: oBundle.getText("Cancel_Text"),
								type: sap.m.ButtonType.Reject,
								tap : function() {
										util.closeCustomDialogWithButton( true );
								}
							}),
				});
		}
		else{
				this.customDialog.destroy();
				this.customDialog = new sap.m.Dialog({
						title: oBundle.getText("Warning"), type : "Message",
						content : [
								new sap.m.Text({
										text: err_message,
										textAlign : "Center",
										wrapping : true
								})
						],
						leftButton: 
							new sap.m.Button({
								text: this.ButtonLabel,
								type: sap.m.ButtonType.Reject,
								tap : function() {
										util.closeCustomDialogWithButton();
								}
							}),
						rightButton: 
							new sap.m.Button({
								text: oBundle.getText("Cancel_Text"),
								type: sap.m.ButtonType.Reject,
								tap : function() {
										util.closeCustomDialogWithButton( true );
								}
							}),
				});
		}
		logTechnicalInfo ( oBundle.getText(err_message), "user is blacklisted", "logged in too many times");
		this.customDialog.open();
}

Utilities.prototype.closeCustomDialogWithButton = function( cancel ) {
	if(this.customDialog !== undefined) this.customDialog.close();
	if ( cancel ) return;
	if (this.action === "signout"){
		userCredentialSettingsController.SignOutAfterCheck();
	}
	else if ( this.action === "forgotpw"){
		//forgotPassword();
		if (forgotPasswordController == undefined)
			forgotPasswordController = sap.ui.controller("app.ui.login.forgotPassword");
		forgotPasswordController.launchforgotPassword();
	}
}

Utilities.prototype.stopPerformanceReading = function(startTime, logMessage){
	var endTime = new Date().getTime();	
	var timeRequired = (endTime - startTime)/1000;
	logPerformanceInfo(logMessage,timeRequired.toString());
}

Utilities.prototype.startPerformanceReading = function(){
	return new Date().getTime();
}

//base64 encoding
Utilities.prototype.encode = function(varInput) {
    var output = "";
    var chr1, chr2, chr3, enc1, enc2, enc3, enc4;
    var i = 0;
    var _keyStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";

    varInput = this._utf8_encode(varInput);

    while (i < varInput.length) {

        chr1 = varInput.charCodeAt(i++);
        chr2 = varInput.charCodeAt(i++);
        chr3 = varInput.charCodeAt(i++);

        enc1 = chr1 >> 2;
        enc2 = ((chr1 & 3) << 4) | (chr2 >> 4);
        enc3 = ((chr2 & 15) << 2) | (chr3 >> 6);
        enc4 = chr3 & 63;

        if (isNaN(chr2)) {
            enc3 = enc4 = 64;
        } else if (isNaN(chr3)) {
            enc4 = 64;
        }

        output = output +
        _keyStr.charAt(enc1) + _keyStr.charAt(enc2) +
        _keyStr.charAt(enc3) + _keyStr.charAt(enc4);

    }

    return output;
};

// base64 decoding
Utilities.prototype.decode = function (varInput) {
    var output = "";
    var chr1, chr2, chr3;
    var enc1, enc2, enc3, enc4;
    var i = 0;
    
    var _keyStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";

    varInput = varInput.replace(/[^A-Za-z0-9\+\/\=]/g, "");

    while (i < varInput.length) {

        enc1 = _keyStr.indexOf(varInput.charAt(i++));
        enc2 = _keyStr.indexOf(varInput.charAt(i++));
        enc3 = _keyStr.indexOf(varInput.charAt(i++));
        enc4 = _keyStr.indexOf(varInput.charAt(i++));

        chr1 = (enc1 << 2) | (enc2 >> 4);
        chr2 = ((enc2 & 15) << 4) | (enc3 >> 2);
        chr3 = ((enc3 & 3) << 6) | enc4;

        output = output + String.fromCharCode(chr1);

        if (enc3 != 64) {
            output = output + String.fromCharCode(chr2);
        }
        if (enc4 != 64) {
            output = output + String.fromCharCode(chr3);
        }

    }

    output = this._utf8_decode(output);

    return output;

};


// base64 UTF-8 encoding
Utilities.prototype._utf8_encode = function(varString) {
    var varString = varString.replace(/\r\n/g, "\n");
    var utftext = "";

    for (var n = 0; n < varString.length; n++) {

        var c = varString.charCodeAt(n);

        if (c < 128) {
            utftext += varString.fromCharCode(c);
        }
        else if ((c > 127) && (c < 2048)) {
            utftext += varString.fromCharCode((c >> 6) | 192);
            utftext += varString.fromCharCode((c & 63) | 128);
        }
        else {
            utftext += varString.fromCharCode((c >> 12) | 224);
            utftext += varString.fromCharCode(((c >> 6) & 63) | 128);
            utftext += varString.fromCharCode((c & 63) | 128);
        }

    }

    return utftext;
};

// base64  UTF-8 decoding
Utilities.prototype._utf8_decode = function(utftext) {
    var varString = "";
    var i = 0;
    var c = c1 = c2 = 0;

    while (i < utftext.length) {

        c = utftext.charCodeAt(i);

        if (c < 128) {
            varString += String.fromCharCode(c);
            i++;
        }
        else if ((c > 191) && (c < 224)) {
            c2 = utftext.charCodeAt(i + 1);
            varString += String.fromCharCode(((c & 31) << 6) | (c2 & 63));
            i += 2;
        }
        else {
            c2 = utftext.charCodeAt(i + 1);
            c3 = utftext.charCodeAt(i + 2);
            varString += String.fromCharCode(((c & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
            i += 3;
        }

    }

    return varString;
};

Utilities.prototype.encodeImageURI = function(imageURI, callback) {
		//console.warn("ENCODING IMAGE NOW");
		var gotFileEntry = function(fileEntry) {
				//console.warn("GOT IMAGE FILE");
				//console.log("got image file entry: " +  fileEntry.fullPath); 
				fileEntry.file( function(file) {
						var reader = new FileReader();
						reader.onloadend = function(evt) {
								//console.warn("READ COMPLETE");
								//console.log("Read complete!");
								var dataURL = evt.target.result;
								callback(dataURL);
						};
						reader.readAsDataURL(file);
				}, function(e){
						//console.warn("!!!!!ENCODING FAILURE!!!!!");
					//console.warn("failure again");
				});
		};

	window.resolveLocalFileSystemURI(imageURI, gotFileEntry, function(e){
		//console.warn("failure in resolving file system");
	}); 	
};

Utilities.prototype.encodeImageURIViaCanvas = function(imageURI, callback) {
	
	var canvasTag = document.createElement("canvas");
    var context = canvasTag.getContext('2d');
    
    var img = new Image();
    img.onload = function(){
      canvasTag.width  = img.width;
      canvasTag.height = img.height;
      context.drawImage(img, 0, 0, img.width, img.height);
      var dataURL = canvasTag.toDataURL();
      callback(dataURL);
    }
    img.src = imageURI;	
	
};

Utilities.prototype.pingAgain = function(){
		var body = {
    		origin:"mLoyalty",
    		traceNo: UUIDv4()
		}
		SmartphoneService.ping(body, homepageController.pingBack);
};


Utilities.prototype.convertDateToReadableFormat = function (dateinms) {
    if (dateinms == null) return null;

    var newDate = new Date(dateinms);

    var theyear = newDate.getFullYear()
    var themonth = newDate.getMonth() + 1
    var thetoday = newDate.getDate()
 
    var fullDate = ( themonth+ "/" + thetoday + "/" + theyear)


   // var fullDate = newDate.getMonth() + " " + newDate.getDay() + " , " + newDate.getYear();
    return fullDate;

};


Utilities.prototype.convertDateToReadableFormatDDMM = function (dateinms) {
    if (dateinms == null) return null;

    var newDate = new Date(dateinms);

    var theyear = newDate.getFullYear()
    var themonth = newDate.getMonth() + 1
    var thetoday = newDate.getDate()

    var fullDate = (themonth + "/" + thetoday )


    // var fullDate = newDate.getMonth() + " " + newDate.getDay() + " , " + newDate.getYear();
    return fullDate;

};

Utilities.prototype.convertDateToReadableFormatDDwordMM = function (dateinms) {
    if (dateinms == null) return null;

    var newDate = new Date(dateinms);
    var theyear = newDate.getFullYear();
    var themonth = newDate.getMonth() + 1;
    var wordmonth = null;
	var thetoday = newDate.getDate();
	
	switch (themonth) {
		case 1:
			wordmonth = "Jan";
			break;
		case 2:
			wordmonth = "Feb";
			break;
		case 3:
			wordmonth = "Mar";
			break;
		case 4:
			wordmonth = "Apr";
			break;
		case 5:
			wordmonth = "May";
			break;
		case 6:
			wordmonth = "Jun";
			break;
		case 7:
			wordmonth = "Jul";
			break;
		case 8:
			wordmonth = "Aug";
			break;
		case 9:
			wordmonth = "Sep";
			break;
		case 10:
			wordmonth = "Oct";
			break;
		case 11:
			wordmonth = "Nov";
			break;
		case 12:
			wordmonth = "Dec";
			break;
	}

    var fullDate = (wordmonth + " " + thetoday )


    // var fullDate = newDate.getMonth() + " " + newDate.getDay() + " , " + newDate.getYear();
    return fullDate;

};



Utilities.prototype.isNumeric = function (input){
		var regexp = /^[0-9]+$/;
		if(regexp .test(input)){
				return true;
		}
		else{
				return false;
		}
		
};


Utilities.prototype.showDialogWithOptions = function( uiCallback,label,btnLabels)
{

	
	/*Phonegap notification section*/
	//console.log("SHOW DIALOG");
	if(navigator != undefined && navigator.notification != undefined)
	{

		
		var buttonLabels = "";
		
		for(var i =0;i<btnLabels.length;i++){
			buttonLabels = buttonLabels + btnLabels[i] + ",";
		}
		if(buttonLabels.length > 0)
			buttonLabels = buttonLabels.substring(0, buttonLabels.length - 1);

		/* Since phonegap's notification runs asynchronously a call back is necessary*/
		
		//console.log("SHOW DIALOG " + buttonLabels);
		
		var CallBack = function(returnIndex)
		{
			uiCallback(returnIndex -1);
		};


		navigator.notification.confirm(label, CallBack,oBundle.getText("application_name"), buttonLabels);
		//console.log("Calling a phonegap alert");

	}

	/* UI5 Dialog is used in case of browser mode*/
	else
	{
		//console.log("Running on browser mode ");
	}


};


/*
 * Below function is to sort an array object based on a key
 */
Utilities.prototype.sortByKey = function(array, key) {
    return array.sort(function(a, b) {
        var x = a[key]; var y = b[key];
        return ((x < y) ? -1 : ((x > y) ? 1 : 0));
    });
};

/*
 * Below function is to sort an array object based on a key without considering the case
 */
Utilities.prototype.sortByKeyIgnoreCase = function(array, key) {
    return array.sort(function(a, b) {
        var x = a[key]; var y = b[key];
     
        return ((x.toLowerCase() < y.toLowerCase()) ? -1 : ((x.toLowerCase() > y.toLowerCase()) ? 1 : 0));
    });
};

/*
 * Below function is to sort an array object based on a key without considering the case and also checks the null value
 */
Utilities.prototype.sortByKeyIgnoreCaseCheckNull = function(array, key) {
    return array.sort(function(a, b) {
        var x = ""+a[key]; var y = ""+b[key];
        
        return ((x.toLowerCase() < y.toLowerCase()) ? -1 : ((x.toLowerCase() > y.toLowerCase()) ? 1 : 0));
    });
};
/*
 * Below function is to sort an array object based on a key "Price"
 */
Utilities.prototype.sortByKeyPrice = function(array, key) {
    return array.sort(function(a, b) {
        var x = a[key]; var y = b[key];
        return x - y;
    });
};

/*
 * Below function is to check if the app is running on an iOS device
 */
Utilities.prototype.isIPhone = function() {
	if( (window.cordova || window.Cordova) && device.platform && device.platform.toLowerCase() === "ios" )
		return true;
	return false;
};

/*
 * Below function is to check if the app is running on an android device
 */
Utilities.prototype.isAndroid = function() {
	if( (window.cordova || window.Cordova) && device.platform && device.platform.toLowerCase() === "android" )
		return true;
	return false;
};


/*
 *scan barcode
 */
Utilities.prototype.createAndroidManualEntryPrompt = function(serviceCall){
	this.manualScanEntryServiceCall = serviceCall;
	
	if (this.androidManualEntryPromptDialog == undefined){
		this.androidManualEntryPromptDialog = new sap.m.Dialog({
			title : oBundle.getText("EnterManually"),
			content : [
			    new sap.m.Text({
			    	text: oBundle.getText("Would_you_like_to_enter_the_barcode")
			    })
			],
			leftButton: 
				new sap.m.Button({
					text: oBundle.getText("No"),
					type: sap.m.ButtonType.Reject,
					tap : function() {
							util.androidManualEntryPromptDialog.close();
				}
			}),
			rightButton: 
				new sap.m.Button({
					text: oBundle.getText("Yes"),
					type: sap.m.ButtonType.Accept,
					tap : function() {
							util.androidManualEntryPromptDialog.close();
							util.createCustomScanDialog(util.manualScanEntryServiceCall);
				}
			}),
		 }); 
	}
	this.androidManualEntryPromptDialog.open();
}

Utilities.prototype.createCustomScanDialog = function ( serviceCall ) {
	this.manualScanEntryServiceCall = serviceCall;
	if (this.customScanDialog == undefined) {
		
		var btnManual = new sap.m.Button('manualBarcodeButton',{
			//TODO: TRANSLATION
			text: oBundle.getText("scan"),
			width: "100%",
			type: sap.m.ButtonType.Accept ,
			tap : function() {
				var result = {
					text : "",
				};
				var obj = {
					storeId : "",	
				};
				if ( sap.ui.getCore().byId("manualBarcodeInput").getValue()!= "" ) {
					if (util.manualScanEntryServiceCall == "listDetail") {
						//console.warn ( sap.ui.getCore().byId("manualBarcodeInput").getValue() );
						result.text = sap.ui.getCore().byId("manualBarcodeInput").getValue();
						util.createBusyDialog(oBundle.getText("Loading"),oBundle.getText("Loading"));
						SmartphoneService.decodeBarcode( result ,listDetailController.scanItemDetailBack);
					}
					else if (util.manualScanEntryServiceCall == "checkInShopping") {
						//console.warn ( sap.ui.getCore().byId("manualBarcodeInput").getValue() );
						result.text = sap.ui.getCore().byId("manualBarcodeInput").getValue();
						result.storeId = app.getPage(ID_CHECK_IN).getContent()[0].getModel().getData().storeDetail.storeId;
						result.listID = checkInSelectMyListsController.checkedLists;
						util.createBusyDialog(oBundle.getText("Loading"),oBundle.getText("Loading"));
						SmartphoneService.decodeBarcodeAndUpdatePickList( result ,checkInShoppingController.scanItemDetailBack);
					}
					else if (util.manualScanEntryServiceCall == "storeCheckIn") {
						//console.warn ( sap.ui.getCore().byId("manualBarcodeInput").getValue() );
						var temp ={
							storeCode: sap.ui.getCore().byId("manualBarcodeInput").getValue(),
						}
						SmartphoneService.getStoreCheckinInfo( temp, checkInController.checkInScanBack);
					}
					else if ( util.manualScanEntryServiceCall == "checkoutScan") {
						//console.warn ( sap.ui.getCore().byId("manualBarcodeInput").getValue() );
						storeId = sap.ui.getCore().byId("manualBarcodeInput").getValue();
						opticalScannerCheckoutController.checkoutScanBack(storeId);
					}
					//close dialog service call with code go to itemDetail
					util.customScanDialog.close();
					//need to reset dialog
					sap.ui.getCore().byId("manualBarcodeInput").setValue("")
				}
				else{
					alert( oBundle.getText("error_message_missing_entry") );
				}
			}
		});
		
		var btnCancel = new sap.m.Button({
			//TODO: TRANSLATION
			text: oBundle.getText("Cancel"),
			width: "100%",
			type: sap.m.ButtonType.Reject ,
			tap : function() {
				//close dialog service call with code go to itemDetail
				util.customScanDialog.close();
				//need to reset dialog
				sap.ui.getCore().byId("manualBarcodeInput").setValue("")
			}
		});
		
		this.customScanDialog = new sap.m.Dialog({
			title:  oBundle.getText("EnterManually"),
			type: sap.m.DialogType.Standard,
			content: [
				new sap.m.Input('manualBarcodeInput',{
					//TODO TRANSLATION
					width: "100%",
					placeholder: oBundle.getText("barcode"),
				})],
			leftButton: btnCancel,
			rightButton: btnManual
		 }); 
	}
	this.customScanDialog.open();
}

Utilities.prototype.isValidDateObject = function ( d ) {
	if (d instanceof Date) {
		// it is a date
		if ( isNaN( d.getTime() ) ) {  
			// date is not valid
			return false;
		}
		else {
			// date is valid
			return true;
		}
	}
	return false;
}

Utilities.prototype.isShoppingSessionExpired = function(response){
	
	if(response.shoppingSessionExpired == true){
		
		util.closeBusyDialog();
		
		var callBackFunction = function(selectedButtonIndex){
			//console.log("Taking the User to CheckIn Screen, after shopping session expired");
			sliderMenuController.checkInSliderViewModFunction(false);
			if (checkInController == undefined) 
		    	checkInController = sap.ui.controller("app.ui.myLists.checkIn");
		    checkInController.launchCheckInPage();
		};
		
		util.showDialogWithOptions(callBackFunction,
				oBundle.getText("shopping_session_expired"),
				[oBundle.getText("OK")]);
		return true;
	}
	return false;
}
