//  2012 SAP AG. All rights reserved.
// Author : SAP.

function CustomGoogleMap() {
	this.infoBubble_ = null; // the only info bubble window
	this.markers_ = [];
}

CustomGoogleMap.prototype.handleTabFunc = null;

/**
 * Default maximum width for the info bubble window
 * @const
 * @private
 */
CustomGoogleMap.prototype.MAX_WIDTH_INFO_BUBBLE_ = 250;

/**
 * Default css class for info bubble background
 * @const
 * @private
 */
CustomGoogleMap.prototype.CSS_CLASS_INFO_BUBBLE_BACKGROUND_ = 'info_bubble_background';

// Trigger the clicks on the specified marker to open the appropriate infowindow
CustomGoogleMap.prototype.triggerClickOnMarker = function(i) {
    if (this.markers_ == null || this.markers_.length <= i) {
        // do nothing
        return;
    } else {
        google.maps.event.trigger(this.markers_[i], "click");
    }
}

CustomGoogleMap.prototype.clearOverlays = function() {
//console.warn("googlemapcontrol  CLEAROVERLAYS");
  //clear previous overlays
    for(var i=0; i < this.markers_.length; i++){
        this.markers_[i].setMap(null);
    }
    this.markers_ = new Array();
}

/**
 * Draw google map on the div with the specified id
 * 
 * @param {string} mapConvasId The id of the div to draw map on  
 * @param {array} locations The array containing the list of locations to be display
 * 							Each location object shall contain the required property as follows:
 * 							latitude, longitude, contentHtml, markerIcon, markerIconShadow.
 *  
 */
CustomGoogleMap.prototype.drawMap = function(mapCanvasId, locations) {
	// //console.log("DRAW MAP");
	var self = this;
	this.initInfoBubble_();
	var map;
	var mapDiv = document.getElementById(mapCanvasId);
	mapDiv.addEventListener('click', function() {
		if (self.infoBubble_ != null && self.infoBubble_.isOpen()) {
			// close the one from other marker
			self.infoBubble_.close();
		}
	});

	var mapOptions = { // https://developers.google.com/maps/documentation/javascript/reference#MapOptions
		// center : new google.maps.LatLng(lat, long), // default to Palo Alto
		zoom : 8,
		mapTypeId : google.maps.MapTypeId.ROADMAP,
		mapTypeControl : false,
		streetViewControl : false,
	};
	
	map = new google.maps.Map(mapDiv, mapOptions);
	google.maps.event.addListener(map, 'zoom_changed', function() {
	    zoomChangeBoundsListener = 
	        google.maps.event.addListener(map, 'bounds_changed', function(event) {
	            if (this.getZoom() > 15 && this.initialZoom == true) {
	                // Change max/min zoom here
	            	//console.log("Before " + this.getZoom());
	                this.setZoom(15);
	                //console.log("After " + this.getZoom());
	                this.initialZoom = false;
	            }
	        google.maps.event.removeListener(zoomChangeBoundsListener);
	    });
	});
	map.initialZoom = true;
	
	var bounds = new google.maps.LatLngBounds();
	if (mapController.locationPermissionAllowed && mapController.myLocation != undefined 
			&& mapController.myLocation.latitude != undefined
			&& mapController.myLocation.longitude != undefined) {
		//console.log("lat long not null");
		var lat = mapController.myLocation.latitude;
		var long = mapController.myLocation.longitude;
		map.setCenter(new google.maps.LatLng(lat, long));
		// more than one markers. Calculate the new bounds based on all marker
		// location then set center and zoom accordingly
		// Defining the boundries

		// PLACE YOUR LOCATION TO MAP
		var markerLocationData = {
			id : "my Location",
			name : "",
			type : "",
			additionalInfo : "",
			shortAddress : "",
			phone : "",
			webAddress : "",
			location : {
				latitude : lat,
				longitude : long,
			},
		// contentHtml : this.generateContentHtml("start" + '&nbsp;' +
		// "10:00am", "close" + '&nbsp;' + "8:00pm", locations[i].name,
		// locations[i].shortAddress, locations[i].phone)
		};
		var markerLocation = new google.maps.Marker({
			position : new google.maps.LatLng(lat, long),
			map : map,
			icon : new google.maps.MarkerImage(
					"app/ui/googleMaps/img/currentlocation.png"),
			title : "My Location"
		});
		this.bindInfoWindow_(markerLocation, map, markerLocationData);
		bounds.extend(markerLocation.position);
	} else {
		//console.log("lat long are null");
	}

	// BIND YOUR LOCATIONS TO MAP
	if (locations == null || locations.length == 0) {
		return;
	}
	var infoWindow = new google.maps.InfoWindow;
	if (locations.length > 0) {
		//console.warn("stores locations length: " + locations.length);
		for ( var i = 0; i < locations.length; i++) {
			//console.log("cycle: " + i);
			// add markers
			var markerData = {
				id : locations[i].id,
				name : locations[i].name,
				type : locations[i].type,
				additionalInfo : locations[i].additionalInfo,
				shortAddress : locations[i].shortAddress,
				phone : locations[i].phone,
				webAddress : locations[i].webAddress,
				location : {
					latitude : locations[i].location.latitude,
					longitude : locations[i].location.longitude,
				},
				contentHtml : this.generateContentHtml("start" + '&nbsp;'
						+ "10:00am", "close" + '&nbsp;' + "8:00pm",
						locations[i].name, locations[i].shortAddress,
						locations[i].phone)
			};
			var marker = new google.maps.Marker({
				position : new google.maps.LatLng(markerData.location.latitude,
						markerData.location.longitude),
				map : map,
				title : markerData.name
			});
			this.bindInfoWindow_(marker, map, markerData);
			// add the marker to the array
			this.markers_[i] = marker;
			// add marker to bounds list
			bounds.extend(new google.maps.LatLng(markerData.location.latitude,
					markerData.location.longitude));
		}
	}
	// Fit these bounds to the map
	map.fitBounds(bounds);
}

CustomGoogleMap.prototype.generateContentHtml = function(start, end, title, shortAddress, phone) {
// //console.log("GENERATE HTML");
		var contentHtml = '<div id="infoBubbleWindow" class="info_bubble_text">' + '<span class="info_bubble_starttime info_bubble_small_font">' + start + '</span>&nbsp;' + '<span class="info_bubble_endtime info_bubble_small_font">' + end + '</span>' + '<div class="info_bubble_title">' + title + '</div>' + '<div class="info_bubble_desc info_bubble_small_font">' + shortAddress + '</div>' + '<img id="infowindow"/>' + '</div>';
		return contentHtml;
	}

	/** ********* Info Bubble ********** */
	CustomGoogleMap.prototype.initInfoBubble_ = function() {
		this.infoBubble_ = new InfoBubble({
			maxWidth : this.MAX_WIDTH_INFO_BUBBLE_,
			// minWidth:380,
			shadowStyle : 1,
			padding : 0,
			backgroundColor : 'rgba(255,57,57, 0.0)',
			borderRadius : 9,
			arrowSize : 12,
			// borderWidth: 2,
			borderColor : '#2c2c2c',
			disableAutoPan : true,
			hideCloseButton : true,
			arrowPosition : 30,
			backgroundClassName : "info_bubble_background",
			arrowStyle : 1
		});
	}

/**
 * Binds the given marker to the map, infoBubble and event 
 * @private
 */
CustomGoogleMap.prototype.bindInfoWindow_ = function (marker, map, location, nid) {
    // declare the variable locally
    var self = this;
    if( marker.title == "My Location"){
        return;
    }
    else{
        google.maps.event.addListener(marker, 'click', function() {
          if (self.infoBubble_.marker == marker) {
            if (!self.infoBubble_.isOpen()) {
              self.infoBubble_.open(map, marker);
            
              // keep trying to check if the infoBubbleWindow is ready then set the event
              var theInterval = 0;
              theInterval = window.setInterval(function() {
                if (document.getElementById('infoBubbleWindow') != null) {
                  window.clearInterval(theInterval);
                  document.getElementById('infoBubbleWindow').addEventListener('touchstart', function() {
                      //alert("toDetailsPage id: " + location.id);
                      mapController.toDetailsPage(location.id);
                  });
                }
              }, 500);
            } else {
              return;
            }
          } else {
            if (self.infoBubble_.isOpen()) {
              // close the one from other marker
              self.infoBubble_.close();
            }
            
            self.infoBubble_.marker = marker;
            self.infoBubble_.content = location.contentHtml;
            self.infoBubble_.open(map, marker); // open infobubble in 200ms of animation
            
            // keep trying to check if the infoBubbleWindow is ready then set the event 
            var theInterval = 0;
            theInterval = window.setInterval(function() {
              if (document.getElementById('infoBubbleWindow') != null) {
                  window.clearInterval(theInterval);
                  document.getElementById('infoBubbleWindow').addEventListener('touchstart', function() {
                      //alert("toDetailsPage id: " + location.id);
                      mapController.toDetailsPage(location.id);
                  });
              }
            }, 500); 
          }
        });
    }
}