
sap.ui.controller('app.ui.productCatalog.productCategory', {
	index : 0, //Controller variable used to reduce the iteration of for loops. It holds the index to which the category in productCatalogData belongs.
	pageCount : 0, //Tracks the page flow.
	//Method used to alternate between the pages.
	launchProductCategoryPage : function(index,item){
		
		var nextPage;
		productCategoryController.index = index; //Copy the index of catalog from which category was selected.
		
		if(app.getCurrentPage().getId() == "PRODUCT_CATALOG_PAGE")             //If page is coming from Product catalog page then initially set the page to Product category page.
			nextPage = productCategoryController.getCategoryPage("PRODUCT_CATEGORY_PAGE",index,item);
		
		
		else if(app.getCurrentPage().getId() == "PRODUCT_CATEGORY_PAGE")       //else if current page is in Product category page then create a duplicate alternate page.
			nextPage = productCategoryController.getCategoryPage("PRODUCT_CATEGORY_DUPLICATE_PAGE",index,item);
		else  		                                                           //else alternate back to product category page
			nextPage = productCategoryController.getCategoryPage("PRODUCT_CATEGORY_PAGE",index,item);
		
		//Member variable holds the data to be presented in current page.
		var currentListItem = productCategoryController.getProductList(index,item);

		if(currentListItem.catalogPresent.length>0){       //Check to see whether end is reached in category list hierarchy
			app.to(nextPage);
			productCategoryController.pageCount++;
			var categoryHeader = productCategoryController.getCategoryHeaderName(currentListItem);
			app.getCurrentPage().setTitle(categoryHeader);
			app.getCurrentPage().getContent()[0].getModel().setData(currentListItem);
		}
		else{                                              //else call the category view.
			productCategoryController.callCategoryView(item);
		}
	},
	//Returns the page for a specific ID to which data is set in above function.
	getCategoryPage : function(ID,index,item){
		if(app.getPage(ID) == null){
			var productCategoryView = sap.ui.view({
				type : sap.ui.core.mvc.ViewType.XML,
				viewName : "app.ui.productCatalog.productCategory",
				controller : productCategoryController
			});
		
			var productCategoryModel = new sap.ui.model.json.JSONModel();
		
			var productCategoryPage = new sap.m.Page(ID,{
				title : item.categoryName,
				showNavButton : true,
				navButtonText : oBundle.getText("Back_Button"),
				navButtonTap : function(){
					
					productCategoryController.pageCount--;
					if(productCategoryController.pageCount>0){
					//Get the current page data and find the its parents value.
					var data = app.getCurrentPage().getContent()[0].getModel().getData();
					var previousListItem = productCategoryController.getProductParentList(productCategoryController.index,data);
					var categoryHeader = productCategoryController.getCategoryHeaderName(previousListItem);
					app.getPreviousPage().setTitle(categoryHeader);
					app.getPreviousPage().getContent()[0].getModel().setData(previousListItem);
					app.back();
					}
					else{
						app.back();
					}
						
				},
				content : [productCategoryView],	
			
			});
			productCategoryView.setModel(productCategoryModel);
		
			app.addPage(productCategoryPage);
		}
		return app.getPage(ID);
	},
	//Whenever an item in list hierarchy is selected get item details and alternate between pages.
	changeCategory : function(ev){
		var categorySource = ev.getSource();
		var itemSelected = categorySource.getBindingContext().getProperty(categorySource.getBindingContext().getPath());
		productCategoryController.launchProductCategoryPage(productCategoryController.index,itemSelected);
	},
	//Get the data for the list item to be displayed in current page.
	getProductList: function(index,item){
		var catalog = {
				catalogPresent : []
		};
		
		for(var j=0; j<productCatalogData.catalog[index].category.length;j++){
			if(productCatalogData.catalog[index].category[j].parentID == item.categoryID){
				catalog.catalogPresent.push(productCatalogData.catalog[index].category[j]);
			}
		}
		return catalog;
	},
	//Get the data for the list item to be displayed in previous page when back button is pressed.
	getProductParentList: function(index,item){
		var catalog = {
				catalogPresent : []
		};
		var parentID = item.catalogPresent[0].parentID;
		for(var j=0; j<productCatalogData.catalog[index].category.length;j++){
			if(productCatalogData.catalog[index].category[j].categoryID == parentID){
				for(var i=0; i<productCatalogData.catalog[index].category.length;i++){
					if(productCatalogData.catalog[index].category[j].parentID == productCatalogData.catalog[index].category[i].parentID)
						catalog.catalogPresent.push(productCatalogData.catalog[index].category[i]);
				}
			}
		}
		return catalog;
	},
	//Method that calls the item details page for a category once list hierarchy has reached its end.
	callCategoryView: function(item){
		if(productCatalogItemDetailController == undefined){
			productCatalogItemDetailController = sap.ui.controller("app.ui.productCatalog.productCatalogItemDetail");
		}
		productCatalogItemDetailController.launchProductCatalogItemDetails(productCategoryController.index,item);
	},
	//Method used to get the header names of page forboth backward and forward navigation.
	getCategoryHeaderName: function(headerName){
		var parentID = headerName.catalogPresent[0].parentID;
		for(var j=0; j<productCatalogData.catalog[productCategoryController.index].category.length;j++){
			if(productCatalogData.catalog[productCategoryController.index].category[j].categoryID == parentID){
				return productCatalogData.catalog[productCategoryController.index].category[j].categoryName;
			}
		}
	}
});
